package App::IndonesianNumberUtils;

use 5.010001;

our $DATE = '2019-11-21'; # DATE
our $VERSION = '0.031'; # VERSION

1;
# ABSTRACT: CLIs related to Indonesian numbers (NIK, NOPPBB, NPWP, etc)

__END__

=pod

=encoding UTF-8

=head1 NAME

App::IndonesianNumberUtils - CLIs related to Indonesian numbers (NIK, NOPPBB, NPWP, etc)

=head1 VERSION

This document describes version 0.031 of App::IndonesianNumberUtils (from Perl distribution App-IndonesianNumberUtils), released on 2019-11-21.

=head1

This distribution contains several CLI's related to Indonesian numbers:

=over

=item * L<parse-nik>

=item * L<parse-nkk>

=item * L<parse-nop-pbb>

=item * L<parse-npwp>

=item * L<parse-pom-reg-code>

=item * L<parse-sim>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-IndonesianNumberUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-IndonesianNumberUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-IndonesianNumberUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2018, 2016, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
